FindReplace Example
===============================================================================

:download:`find_replace.enaml <../../../examples/layout/advanced/find_replace.enaml>`

.. literalinclude:: ../../../examples/layout/advanced/find_replace.enaml
    :language: python

::

 $ enaml-run find_replace.enaml

.. image:: images/find_replace.png
